# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowRunFailedEnvironment = typing.Union[typing.Literal["development", "preview", "production", "test"], typing.Any]
