# This file was auto-generated by Fern from our API Definition.

from .types import WorkflowsRunRequestInputsValue, WorkflowsRunStreamRequestInputsValue

__all__ = ["WorkflowsRunRequestInputsValue", "WorkflowsRunStreamRequestInputsValue"]
