# This file was auto-generated by Fern from our API Definition.

import typing
from .documents_create_request_zero_value import DocumentsCreateRequestZeroValue
from .documents_create_request_item_value import DocumentsCreateRequestItemValue

DocumentsCreateRequest = typing.Union[
    typing.Dict[str, DocumentsCreateRequestZeroValue], typing.List[typing.Dict[str, DocumentsCreateRequestItemValue]]
]
