# This file was auto-generated by Fern from our API Definition.

from .types import (
    DocumentsCreateRequest,
    DocumentsCreateRequestItemValue,
    DocumentsCreateRequestZeroValue,
    DocumentsUpdateRequestValue,
)

__all__ = [
    "DocumentsCreateRequest",
    "DocumentsCreateRequestItemValue",
    "DocumentsCreateRequestZeroValue",
    "DocumentsUpdateRequestValue",
]
