# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .table_config_output import TableConfigOutput
import typing
import datetime as dt
from .identity import Identity
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Table(UncheckedBaseModel):
    table_config: TableConfigOutput
    created_at: typing.Optional[dt.datetime] = None
    last_updated_at: typing.Optional[dt.datetime] = None
    created_by: Identity
    last_updated_by: Identity
    revision_id: str
    table_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
