# This file was auto-generated by Fern from our API Definition.

from .workflows_run_request_inputs_value import WorkflowsRunRequestInputsValue
from .workflows_run_stream_request_inputs_value import WorkflowsRunStreamRequestInputsValue

__all__ = ["WorkflowsRunRequestInputsValue", "WorkflowsRunStreamRequestInputsValue"]
